# Converting MTGs

```@setup usepkg
using MultiScaleTreeGraph
file = joinpath(dirname(dirname(pathof(MultiScaleTreeGraph))),"test","files","simple_plant.mtg")
mtg = read_mtg(file)
```

We can do a lot using the MTG format, but sometimes we want our data in another format.

That's why `MultiScaleTreeGraph.jl` provide functions to convert an MTG into a DataFrame or into a Graph.

## MTG to DataFrame

To convert an MTG into a DataFrame, you can simply use this command:

```@example usepkg
df = DataFrame(mtg, :Width)
```

This will convert your MTG into a DataFrame along with the selected variable (here the Width). The node MTG is always reported in new columns:

- tree: a pretty-printing of the MTG
- id: the unique ID of the node, taken from the node name (*e.g.* `mtg.name`)
- symbol: the node symbol
- scale: the node scale
- index: the node index
- parent_id: the node's parent id
- link: the link between the node and its parent

It is also possible to get several attributes as columns by passing their names as a vector:

```@example usepkg
DataFrame(mtg, [:Width, :Length])
```

## MTG to MetaGraph

We can convert an MTG into a MetaGraph using `MetaGraph()`:

```@example usepkg
mg = MetaGraph(mtg)
```

This is particularly useful if you want to benefit from the algorithm provided by [Graphs.jl](https://github.com/JuliaGraphs/Graphs.jl) and [MetaGraphsNext.jl](https://github.com/JuliaGraphs/MetaGraphsNext.jl), such as writing into more standard formats such as DOTFormat or MGFormat (or any other available from [GraphIO.jl](https://github.com/JuliaGraphs/GraphIO.jl)), plotting with [GraphPlot.jl](https://juliagraphs.org/GraphPlot.jl/) or [NetworkLayout.jl](https://github.com/JuliaGraphs/NetworkLayout.jl), or computing *e.g.* flow with [GraphsFlows.jl](https://github.com/JuliaGraphs/GraphsFlows.jl).
