# Plotting

```@setup usepkg
using MultiScaleTreeGraph
using Plots

file = joinpath(dirname(dirname(pathof(MultiScaleTreeGraph))),"test","files","simple_plant.mtg")
mtg = read_mtg(file)
```

The package provides plots recipes to plot MTGs.

To do so, you just have to use the `Plots` package, and choose a backend. Let's choose the plotly backend for our example:

```@example usepkg
using Plots
# import Pkg; Pkg.add("PlotlyJS")
plotlyjs()

file = joinpath(dirname(dirname(pathof(MultiScaleTreeGraph))),"test","files","simple_plant.mtg")
mtg = read_mtg(file)

plot(mtg)
savefig("mtgplot.html"); nothing # hide
```

```@raw html
<object type="text/html" data="mtgplot.html" style="width:100%;height:500px;"></object>
```

The default plot is a 2D projection of the MTG. You an also get a 3D projection using the `mode` keyword argument:

```julia
plot(mtg, mode = "3d")
```

```@raw html
<object type="text/html" data="../mtgplot3d.html" style="width:100%;height:500px;"></object>
<!-- NB: this plot is made in get_started.md -->
```
